@@ -5,16 +5,16 @@
 */
 
 #include "extractHereDndPlugin.h"
+#include "archive_kerfuffle.h"
 #include "ark_debug.h"
 #include "batchextract.h"
-#include "archive_kerfuffle.h"
 #include "pluginmanager.h"
 
 #include <QAction>
 
 #include <KFileItemListProperties>
-#include <KPluginFactory>
 #include <KLocalizedString>
+#include <KPluginFactory>
 
 K_PLUGIN_CLASS_WITH_JSON(ExtractHereDndPlugin, "ark_dndextract.json")
 
@@ -26,7 +26,7 @@ void ExtractHereDndPlugin::slotTriggered()
     batchJob->setAutoSubfolder(true);
     batchJob->setDestinationFolder(m_dest.toDisplayString(QUrl::PreferLocalFile));
     batchJob->setPreservePaths(true);
-    for (const QUrl& url : std::as_const(m_urls)) {
+    for (const QUrl &url : std::as_const(m_urls)) {
         batchJob->addInput(url);
     }
 
@@ -34,13 +34,12 @@ void ExtractHereDndPlugin::slotTriggered()
     batchJob->start();
 }
 
-ExtractHereDndPlugin::ExtractHereDndPlugin(QObject* parent, const QVariantList&)
-        : KIO::DndPopupMenuPlugin(parent)
+ExtractHereDndPlugin::ExtractHereDndPlugin(QObject *parent, const QVariantList &)
+    : KIO::DndPopupMenuPlugin(parent)
 {
 }
 
-QList<QAction *> ExtractHereDndPlugin::setup(const KFileItemListProperties& popupMenuInfo,
-                                             const QUrl& destination)
+QList<QAction *> ExtractHereDndPlugin::setup(const KFileItemListProperties &popupMenuInfo, const QUrl &destination)
 {
     QList<QAction *> actionList;
 
@@ -54,8 +53,7 @@ QList<QAction *> ExtractHereDndPlugin::setup(const KFileItemListProperties& popu
 
     const QString extractHereMessage = i18nc("@action:inmenu Context menu shown when an archive is being drag'n'dropped", "Extract here");
 
-    QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("archive-extract")),
-                                  extractHereMessage, nullptr);
+    QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("archive-extract")), extractHereMessage, nullptr);
     connect(action, &QAction::triggered, this, &ExtractHereDndPlugin::slotTriggered);
 
     actionList.append(action);
