@@ -18,7 +18,10 @@ class CopyTest : public AbstractAddTest
     Q_OBJECT
 
 public:
-    CopyTest() : AbstractAddTest() {}
+    CopyTest()
+        : AbstractAddTest()
+    {
+    }
 
 private Q_SLOTS:
     void testCopying_data();
@@ -30,31 +33,26 @@ QTEST_GUILESS_MAIN(CopyTest)
 void CopyTest::testCopying_data()
 {
     QTest::addColumn<QString>("archiveName");
-    QTest::addColumn<Plugin*>("plugin");
-    QTest::addColumn<QVector<Archive::Entry*>>("targetEntries");
-    QTest::addColumn<Archive::Entry*>("destination");
+    QTest::addColumn<Plugin *>("plugin");
+    QTest::addColumn<QVector<Archive::Entry *>>("targetEntries");
+    QTest::addColumn<Archive::Entry *>("destination");
     QTest::addColumn<QStringList>("expectedNewPaths");
     QTest::addColumn<uint>("numberOfEntries");
 
     setupRows(QStringLiteral("copy a single file"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("a.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
-                  QStringLiteral("empty_dir/a.txt")
-              },
+              QStringList{QStringLiteral("empty_dir/a.txt")},
               14);
 
     setupRows(QStringLiteral("copy several files"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
-                  new Archive::Entry(this, QStringLiteral("a.txt")),
-                  new Archive::Entry(this, QStringLiteral("b.txt"))
-              },
+              QVector<Archive::Entry *>{new Archive::Entry(this, QStringLiteral("a.txt")), new Archive::Entry(this, QStringLiteral("b.txt"))},
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("empty_dir/a.txt"),
                   QStringLiteral("empty_dir/b.txt"),
               },
@@ -62,77 +60,73 @@ void CopyTest::testCopying_data()
 
     setupRows(QStringLiteral("copy a root directory"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("empty_dir/dir1/"),
                   QStringLiteral("empty_dir/dir1/dir/"),
                   QStringLiteral("empty_dir/dir1/dir/a.txt"),
                   QStringLiteral("empty_dir/dir1/dir/b.txt"),
                   QStringLiteral("empty_dir/dir1/a.txt"),
-                  QStringLiteral("empty_dir/dir1/b.txt")
+                  QStringLiteral("empty_dir/dir1/b.txt"),
               },
               19);
 
     setupRows(QStringLiteral("copy a root directory 2"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir2/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("empty_dir/dir2/"),
                   QStringLiteral("empty_dir/dir2/dir/"),
                   QStringLiteral("empty_dir/dir2/dir/a.txt"),
-                  QStringLiteral("empty_dir/dir2/dir/b.txt")
+                  QStringLiteral("empty_dir/dir2/dir/b.txt"),
               },
               17);
 
     setupRows(QStringLiteral("copy a root directory 3"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir2/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("dir1/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("dir1/dir2/"),
                   QStringLiteral("dir1/dir2/dir/"),
                   QStringLiteral("dir1/dir2/dir/a.txt"),
-                  QStringLiteral("dir1/dir2/dir/b.txt")
+                  QStringLiteral("dir1/dir2/dir/b.txt"),
               },
               17);
 
     setupRows(QStringLiteral("copy a directory"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
-                  QStringLiteral("empty_dir/dir/"),
-                  QStringLiteral("empty_dir/dir/a.txt"),
-                  QStringLiteral("empty_dir/dir/b.txt")
-              },
+              QStringList{QStringLiteral("empty_dir/dir/"), QStringLiteral("empty_dir/dir/a.txt"), QStringLiteral("empty_dir/dir/b.txt")},
               16);
 
     setupRows(QStringLiteral("copy several directories"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
@@ -142,10 +136,10 @@ void CopyTest::testCopying_data()
                   new Archive::Entry(this, QStringLiteral("dir2/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("empty_dir/dir1/"),
                   QStringLiteral("empty_dir/dir1/dir/"),
                   QStringLiteral("empty_dir/dir1/dir/a.txt"),
@@ -155,59 +149,59 @@ void CopyTest::testCopying_data()
                   QStringLiteral("empty_dir/dir2/"),
                   QStringLiteral("empty_dir/dir2/dir/"),
                   QStringLiteral("empty_dir/dir2/dir/a.txt"),
-                  QStringLiteral("empty_dir/dir2/dir/b.txt")
+                  QStringLiteral("empty_dir/dir2/dir/b.txt"),
               },
               23);
 
     setupRows(QStringLiteral("copy several entries"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("empty_dir/dir/"),
                   QStringLiteral("empty_dir/dir/a.txt"),
                   QStringLiteral("empty_dir/dir/b.txt"),
                   QStringLiteral("empty_dir/a.txt"),
-                  QStringLiteral("empty_dir/b.txt")
+                  QStringLiteral("empty_dir/b.txt"),
               },
               18);
 
     setupRows(QStringLiteral("copy a directory inside itself"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("dir1/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("dir1/dir1/"),
                   QStringLiteral("dir1/dir1/dir/"),
                   QStringLiteral("dir1/dir1/dir/a.txt"),
                   QStringLiteral("dir1/dir1/dir/b.txt"),
                   QStringLiteral("dir1/dir1/a.txt"),
-                  QStringLiteral("dir1/dir1/b.txt")
+                  QStringLiteral("dir1/dir1/b.txt"),
               },
               19);
 
     setupRows(QStringLiteral("copy a directory to the root"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
               },
               new Archive::Entry(this, QString()),
-              QStringList {
+              QStringList{
                   QStringLiteral("dir/"),
                   QStringLiteral("dir/a.txt"),
                   QStringLiteral("dir/b.txt"),
@@ -223,7 +217,7 @@ void CopyTest::testCopying()
     const QString archivePath = temporaryDir.path() + QLatin1Char('/') + archiveName;
     QVERIFY(QFile::copy(QFINDTESTDATA(QStringLiteral("data/") + archiveName), archivePath));
 
-    QFETCH(Plugin*, plugin);
+    QFETCH(Plugin *, plugin);
     QVERIFY(plugin);
 
     auto loadJob = Archive::load(archivePath, plugin);
@@ -240,8 +234,8 @@ void CopyTest::testCopying()
         QSKIP("Could not find a plugin to handle the archive. Skipping test.", SkipSingle);
     }
 
-    QFETCH(QVector<Archive::Entry*>, targetEntries);
-    QFETCH(Archive::Entry*, destination);
+    QFETCH(QVector<Archive::Entry *>, targetEntries);
+    QFETCH(Archive::Entry *, destination);
     QFETCH(QStringList, expectedNewPaths);
 
     // Retrieve current paths in the archive.
