@@ -18,7 +18,10 @@ class MoveTest : public AbstractAddTest
     Q_OBJECT
 
 public:
-    MoveTest() : AbstractAddTest() {}
+    MoveTest()
+        : AbstractAddTest()
+    {
+    }
 
 private Q_SLOTS:
     void testMoving_data();
@@ -30,88 +33,73 @@ QTEST_GUILESS_MAIN(MoveTest)
 void MoveTest::testMoving_data()
 {
     QTest::addColumn<QString>("archiveName");
-    QTest::addColumn<Plugin*>("plugin");
-    QTest::addColumn<QVector<Archive::Entry*>>("targetEntries");
-    QTest::addColumn<Archive::Entry*>("destination");
+    QTest::addColumn<Plugin *>("plugin");
+    QTest::addColumn<QVector<Archive::Entry *>>("targetEntries");
+    QTest::addColumn<Archive::Entry *>("destination");
     QTest::addColumn<QStringList>("expectedNewPaths");
     QTest::addColumn<uint>("numberOfEntries");
 
     setupRows(QStringLiteral("replace a single file"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("a.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/a.txt")),
-              QStringList {
-                  QStringLiteral("empty_dir/a.txt")
-              },
+              QStringList{QStringLiteral("empty_dir/a.txt")},
               13);
 
     setupRows(QStringLiteral("replace several files"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("a.txt")),
-                  new Archive::Entry(this, QStringLiteral("b.txt"))
+                  new Archive::Entry(this, QStringLiteral("b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
-                  QStringLiteral("empty_dir/a.txt"),
-                  QStringLiteral("empty_dir/b.txt")
-              },
+              QStringList{QStringLiteral("empty_dir/a.txt"), QStringLiteral("empty_dir/b.txt")},
               13);
 
     setupRows(QStringLiteral("replace a root directory"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
-                  QStringLiteral("empty_dir/a.txt"),
-                  QStringLiteral("empty_dir/b.txt"),
-                  QStringLiteral("empty_dir/dir/"),
-                  QStringLiteral("empty_dir/dir/a.txt"),
-                  QStringLiteral("empty_dir/dir/b.txt")
-              },
+              QStringList{QStringLiteral("empty_dir/a.txt"),
+                          QStringLiteral("empty_dir/b.txt"),
+                          QStringLiteral("empty_dir/dir/"),
+                          QStringLiteral("empty_dir/dir/a.txt"),
+                          QStringLiteral("empty_dir/dir/b.txt")},
               13);
 
     setupRows(QStringLiteral("replace a root directory 2"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir2/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/dir/")),
-              QStringList {
-                  QStringLiteral("empty_dir/dir/"),
-                  QStringLiteral("empty_dir/dir/a.txt"),
-                  QStringLiteral("empty_dir/dir/b.txt")
-              },
+              QStringList{QStringLiteral("empty_dir/dir/"), QStringLiteral("empty_dir/dir/a.txt"), QStringLiteral("empty_dir/dir/b.txt")},
               13);
 
     setupRows(QStringLiteral("replace a directory"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/dir/")),
-              QStringList {
-                  QStringLiteral("empty_dir/dir/"),
-                  QStringLiteral("empty_dir/dir/a.txt"),
-                  QStringLiteral("empty_dir/dir/b.txt")
-              },
+              QStringList{QStringLiteral("empty_dir/dir/"), QStringLiteral("empty_dir/dir/a.txt"), QStringLiteral("empty_dir/dir/b.txt")},
               13);
 
     setupRows(QStringLiteral("replace several directories"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
@@ -121,10 +109,10 @@ void MoveTest::testMoving_data()
                   new Archive::Entry(this, QStringLiteral("dir2/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir2/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir2/dir/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("empty_dir/dir1/"),
                   QStringLiteral("empty_dir/dir1/a.txt"),
                   QStringLiteral("empty_dir/dir1/b.txt"),
@@ -134,49 +122,45 @@ void MoveTest::testMoving_data()
                   QStringLiteral("empty_dir/dir2/"),
                   QStringLiteral("empty_dir/dir2/dir/"),
                   QStringLiteral("empty_dir/dir2/dir/a.txt"),
-                  QStringLiteral("empty_dir/dir2/dir/b.txt")
+                  QStringLiteral("empty_dir/dir2/dir/b.txt"),
               },
               13);
 
     setupRows(QStringLiteral("replace several entries"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
                   new Archive::Entry(this, QStringLiteral("dir1/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("empty_dir/")),
-              QStringList {
+              QStringList{
                   QStringLiteral("empty_dir/dir/"),
                   QStringLiteral("empty_dir/dir/a.txt"),
                   QStringLiteral("empty_dir/dir/b.txt"),
                   QStringLiteral("empty_dir/a.txt"),
-                  QStringLiteral("empty_dir/b.txt")
+                  QStringLiteral("empty_dir/b.txt"),
               },
               13);
 
     setupRows(QStringLiteral("move a directory to the root"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> {
+              QVector<Archive::Entry *>{
                   new Archive::Entry(this, QStringLiteral("dir1/dir/")),
                   new Archive::Entry(this, QStringLiteral("dir1/dir/a.txt")),
-                  new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt"))
+                  new Archive::Entry(this, QStringLiteral("dir1/dir/b.txt")),
               },
               new Archive::Entry(this, QStringLiteral("dir/")),
-              QStringList {
-                  QStringLiteral("dir/"),
-                  QStringLiteral("dir/a.txt"),
-                  QStringLiteral("dir/b.txt")
-              },
+              QStringList{QStringLiteral("dir/"), QStringLiteral("dir/a.txt"), QStringLiteral("dir/b.txt")},
               13);
 
     setupRows(QStringLiteral("rename a file in the root (bug #368530)"),
               QStringLiteral("test"),
-              QVector<Archive::Entry*> { new Archive::Entry(this, QStringLiteral("a.txt")) },
+              QVector<Archive::Entry *>{new Archive::Entry(this, QStringLiteral("a.txt"))},
               new Archive::Entry(this, QStringLiteral("new-name.txt")),
-              QStringList { QStringLiteral("new-name.txt") },
+              QStringList{QStringLiteral("new-name.txt")},
               13);
 }
 
@@ -188,7 +172,7 @@ void MoveTest::testMoving()
     const QString archivePath = temporaryDir.path() + QLatin1Char('/') + archiveName;
     QVERIFY(QFile::copy(QFINDTESTDATA(QStringLiteral("data/") + archiveName), archivePath));
 
-    QFETCH(Plugin*, plugin);
+    QFETCH(Plugin *, plugin);
     QVERIFY(plugin);
 
     auto loadJob = Archive::load(archivePath, plugin);
@@ -203,8 +187,8 @@ void MoveTest::testMoving()
         QSKIP("Could not find a plugin to handle the archive. Skipping test.", SkipSingle);
     }
 
-    QFETCH(QVector<Archive::Entry*>, targetEntries);
-    QFETCH(Archive::Entry*, destination);
+    QFETCH(QVector<Archive::Entry *>, targetEntries);
+    QFETCH(Archive::Entry *, destination);
     QFETCH(QStringList, expectedNewPaths);
 
     // Retrieve current paths in the archive.
